@@ -1,7 +1,8 @@
-#!/usr/bin/env python
+
+
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.6.0-2
-# Date 17 February 2010
+# Application Name - Health Check V0.6.0-3
+#Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
 #
@@ -23,9 +24,9 @@
 # Import the libraries needed in this program
 # Basic ones
 # import PyQt4 & sys
+print "** Start Imports **"
 from PyQt4 import QtCore, QtGui
 import sys
-# import osso
 # To allow os.popen ('<<Terminal command>>').read() commands
 import os
 
@@ -34,38 +35,37 @@ import subprocess
 
 # GPS ones
 import location
-import gobject
+
 
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
 import gn_cellinfo
-import gtk
+
 import hildon
-import pygtk
+#import pygtk
 
 #for phone orientation call
 import dbus.glib
 
-#For bluetooth - apt-get install python-bluetooth
-#import bluetooth
-# osso_c = osso.Context("healthcheck", "666", True)
-
-#Threading imports!
 from threading import Thread
 import time
+import gtk
 gtk.gdk.threads_init()
 
-
+import gobject
+print "** Finish Imports **"
 
 
 # Set a global variable - used to send the GPS info from a function back onto its label in the GUI. I'm sure there is a much better way returning
 # the variable in a function, but this works.... Example: http://www.wellho.net/resources/ex.php4?item=y105/locvar.py
 # Setting it to "location" for now.
+print "** Seting global variable **"
 var_g_GPS = "No GPS lock"
-var_g_ALT = "altitude"
+
 
 class Ui_MainWindow(object):
     def setupUi(self, MainWindow):
+        print "** start SetupUi**"
         # declaring the previous var_g_GPS location as a global in here, this allows it to be read in here.
         global var_g_GPS
 
@@ -239,7 +239,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.6.0-2 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.6.0-3 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -254,18 +254,23 @@ class Ui_MainWindow(object):
         self.menubar.setObjectName("menubar")
         MainWindow.setMenuBar(self.menubar)
         # Draw the Status bar
-        self.addemptylist1()
-        self.addemptylist2()
+        print "** Add empty lists to tab1 **"
+        self.addemptylist1(MainWindow)
+        print "** Add empty lists to tab2 **"
+        self.addemptylist2(MainWindow)
         # Run the translate UI - Added by QT Designer - i have removed alot of setText's and placed them above.
+        print "** Run retranslateUi **"
         self.retranslateUi(MainWindow)
         #self.updateTab1()
  
         # Set which tab you want showing on program load
+        print "** Show tab1 (0) **"
         self.tabWidget.setCurrentIndex(0)
         QtCore.QMetaObject.connectSlotsByName(MainWindow)
+        
   
 
-    def addemptylist1(self):
+    def addemptylist1(self,MainWindow):
         self.listWidget.clear()
         self.listWidget.addItem("Firmware Version")
         self.listWidget.addItem("Processor Information")
@@ -279,8 +284,9 @@ class Ui_MainWindow(object):
         self.listWidget.addItem("MyDocs")
         self.listWidget.addItem("Rootfs Free")
         self.listWidget.sortItems()
+        print "** Empty List Added**"
 
-    def addemptylist2(self):
+    def addemptylist2(self,MainWindow):
         self.listWidget2.clear()
         self.listWidget2.addItem("Cell ID")
         self.listWidget2.addItem("Cell RNC")
@@ -290,9 +296,11 @@ class Ui_MainWindow(object):
         self.listWidget2.addItem("Internal IP")
         self.listWidget2.addItem("Phone signal")
         self.listWidget2.sortItems()
+        print "** Empty List Added**"
         
 # Funtion - update GPS - Using lib-location
     def updateGPS(self):
+        print "** Updating GPS Info**"
         global var_g_GPS
         global var_g_ALT
         
@@ -307,7 +315,6 @@ class Ui_MainWindow(object):
         device.connect("changed", on_changed, control)
         control.connect("gpsd-stopped", on_stop, loop)
         gobject.idle_add(start_location, control)
-
         loop.run()
 
         # Set the GPS tabel text       
@@ -317,39 +324,38 @@ class Ui_MainWindow(object):
         l = None
         l = os.popen(al).read()
         self.listWidget2.addItem("Internal IP \t\t" + l.strip())
+        print "** Updated GPS Info**"
 
 
     def reboot_sys(self):
-        import gtk
+        print "** reboot function running**"
         self.CloseDialog = QtGui.QMessageBox.question(None, "Time for a Reboot!","Do you really want to reboot?",QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,QtGui.QMessageBox.No)
         if self.CloseDialog == QtGui.QMessageBox.Yes:
-            
+            print "** You pressed yes, rebooting **"
             b = None
             b = os.popen('run-standalone.sh dbus-send --system --type=method_call --dest="com.nokia.dsme" --print-reply "/com/nokia/dsme/request" com.nokia.dsme.request.req_reboot')
             b.close ()
         elif self.CloseDialog == QtGui.QMessageBox.No:
-            print "User pressed 'No' button"
+            print "** User pressed 'No' button - returning **"
 
     def updatesound(self):
-
+        print "** Testing sounds! **"
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
         interface.Notify('HealthCheck', 0, 'general_refresh', 'Sound Test', 'Stereo then Mono Test', [], {}, 3000)
-        
+        print "** Starting STero Test **"
         b = None
         b = os.popen('pacat --channels=2 /usr/share/sounds/ui-wake_up_tune.wav')
         b.close ()
-
+        print "** Starting Mono Test**"
         b = None
         b = os.popen('pacat --channels=1 /usr/share/sounds/ui-wake_up_tune.wav')
         b.close ()
               
-        
-        
-        
 # Funtion - update the front camera image
     def updateImage(self):
+        print "** Starting front camera function **"
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
@@ -365,8 +371,10 @@ class Ui_MainWindow(object):
         image = QtGui.QPixmap(image_file)
         # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
         self.lbl_CameraShow.setPixmap(image)
+        print " ** Finished front camera function **"
 
     def updateImage2(self):
+        print " ** Starting back camera function **"
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
@@ -383,9 +391,11 @@ class Ui_MainWindow(object):
         image = QtGui.QPixmap(image_file)
         # Declare image, and tell it, that it is a pixmap, and it will be a pixmap of the file we have just set.
         self.lbl_CameraShow.setPixmap(image)
+        print " ** Finished Back camera function **"
   
 # Funtion - update Firmware version label
     def updateMaemoV(self):
+        print " ** Getting formware version **"
         # This one reads fremantle version number (Firmware)
         g = os.popen('dpkg -l "mp-fremantle-*"').read()
         g = g.strip()[-15:]
@@ -438,30 +448,34 @@ class Ui_MainWindow(object):
             self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - Early Release Vanilla Variant")
         else:
            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " ")
+           print " ** Finished Maemo Version**"
 
 # Funtion - update CPU Information
     def updateCPU(self):
+        print " ** Getting CPU Info **"
         # This one reads fremantle version number (Firmware)
         ga = os.popen('cat /proc/cpuinfo | grep Processor').read()
         ga = ga.strip()[11:]
         
         self.listWidget.addItem("Processor Information \t" + ga.strip())
-        
+        print " ** Getting board info**"
         gb = os.popen('cat /proc/cpuinfo | grep Hardware').read()
         gb = gb.strip()[11:]
         
         self.listWidget.addItem("N900 Board \t\t\t" + gb.strip())
-
+        print " ** Getting board info revision**"
         gj = os.popen('cat /proc/cpuinfo | grep Revision').read()
         gj = gj.strip()[11:]
         
         self.listWidget.addItem("N900 Board Revision \t" + gj.strip())
 
+        print " ** Getting system locale**"
         gc = os.popen('locale | grep LANG').read()
         gc = gc.strip()[5:]
         
         self.listWidget.addItem("System Locale \t\t" + gc.strip())
 
+        print " ** Getting boot count**"
         gd = os.popen('cat /var/lib/dsme/boot_count').read()
         gd = gd.strip()
         self.listWidget.addItem("Boot Count \t\t\t" + gd.strip())
@@ -472,11 +486,13 @@ class Ui_MainWindow(object):
         self.listWidget.addItem("FM Trans Strength \t\t" + ge.strip())
         
     def updatenetname(self):
+        print " ** Getting host name**"
         ga = os.popen('cat /etc/hostname').read()
         ga = ga.strip()
         self.listWidget2.addItem("Device Hostname \t" + ga.strip())
 
     def updateUptime(self):
+        print " ** Getting system uptime**"
         # This one reads fremantle version number (Firmware)
         ge = os.popen('uptime|cut -d" " -f4-|cut -d"," -f-1').read()
         self.listWidget.addItem("System Uptime \t\t" + ge.strip())
@@ -484,6 +500,7 @@ class Ui_MainWindow(object):
 
 # Funtion - update battery information
     def updateBatt(self):
+        print " ** Getting battery percentage**"
         # This one pulls out the battery percentage
         bg = os.popen('lshal|grep percen').read()
         # This one reads the applications list from dpkg
@@ -499,15 +516,18 @@ class Ui_MainWindow(object):
 
 # Funtion - update Accelerator information
     def updateAccel(self):
+        print " ** Importing dbus.glib **"
         import dbus.glib
+        print " ** Glib done**"
 
         # set f to = the accellerometer co-ordinates
         # the co-ords need to be pulled out and split for easy reading
         # Close down the co-ord file once used (Only displaying static info, not updating yet)
+        print " ** Getting accel co-ords**"
         f = open("/sys/class/i2c-adapter/i2c-3/3-001d/coord", 'r')
         coords = [int(w) for w in f.readline().split()]
         f.close()
-
+        print " ** Getting orientation**"
         b = None
         b = os.popen('run-standalone.sh dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_device_orientation_ind').read()
         
@@ -524,8 +544,11 @@ class Ui_MainWindow(object):
             #print "  %s - %s" % (addr, name)
 
     def vibrateon(self):
+        print " ** importing dbus.glib**"
         import dbus.glib
+        print " ** got dbus.glib**"
 
+        print " ** testing vibrations**"
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
@@ -533,6 +556,7 @@ class Ui_MainWindow(object):
         # set f to = the accellerometer co-ordinates
         # the co-ords need to be pulled out and split for easy reading
         # Close down the co-ord file once used (Only displaying static info, not updating yet)
+        
         bb = 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_activate string:' + "\'PatternTouchscreen\'"
         b = os.popen(bb)
         b.close()
@@ -568,9 +592,12 @@ class Ui_MainWindow(object):
         bb= 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_deactivate string:' + "\'PatternIncomingCall\'"
         b = os.popen(bb)
         b.close()
+        print " ** finished vibrations**"
         
     def updateLED(self):
+        print " ** importing dbus.glib**"
         import dbus.glib
+        print " ** Starting LED Patterns**"
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
@@ -595,12 +622,14 @@ class Ui_MainWindow(object):
         bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_deactivate string:' + "\'PatternCommunicationSMS\'"
         b = os.popen(bb)
         b.close()
+        print " ** Finished LED Patterns **"
 
       
 
 
 # Funtion - update rootfs, currently shows free MB and used %.
     def updaterootfs(self):
+        print " ** Getting rootfs space**"
         # Call the x-terminal command to read the rootfs free space
         gr = os.popen('df -h /').read()
         # Remove some of the faffy bits. I've left the total free and percentage used at the moment, is a little confusing
@@ -610,6 +639,7 @@ class Ui_MainWindow(object):
         self.listWidget.addItem("Rootfs \t\t\t" + gx.strip() + " free")
 
     def updatemydocs(self):
+        print " ** Getting MyDocs space**"
         # Call the x-terminal command to read the rootfs free space
         ge = os.popen('df -h /home/user/MyDocs').read()
         # Remove some of the faffy bits. I've left the total free and percentage used at the moment, is a little confusing
@@ -623,34 +653,29 @@ class Ui_MainWindow(object):
 # Funtion - update tab.... Originally to update tab1, but using it to collate the functions
 # It has the commented out message boxes, will work on this later
     def updateAll(self):
+        print " ** Running Update ALL**"
         self.updateTab1()
         self.updateTab2()
     
     def updateTab1(self):
-        import hildon
+        print " ** Running tab1 update**"
+        #import hildon
         self.listWidget.clear()
         self.pushButton_hw.setEnabled(False)
         self.pushButton_a1.setEnabled(False)
         self.pushButton_hw.setText(".")  
-        #Thread(target=self.updaterootfs()).start()
         self.updaterootfs()
         self.pushButton_hw.setText("..")
-        #Thread(target=self.updateAccel()).start()
         self.updateAccel()
         self.pushButton_hw.setText("...")
-        #Thread(target=self.updateCPU()).start()
         self.updateCPU()
         self.pushButton_hw.setText("....")
-        #Thread(target=self.updatemydocs()).start()
         self.updatemydocs()
         self.pushButton_hw.setText(".....")
         self.updateMaemoV()
-        #Thread(target=self.updateMaemoV()).start()
         self.pushButton_hw.setText("......")
-        #Thread(target=self.updateUptime()).start()
         self.updateUptime()
         self.pushButton_hw.setText(".......")
-        #Thread(target=self.updateBatt()).start()
         self.updateBatt()
         self.pushButton_hw.setText("........")
         self.pushButton_hw.setText("Update Tab")
@@ -661,21 +686,18 @@ class Ui_MainWindow(object):
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
         interface.Notify('HealthCheck', 0, 'general_refresh', 'System Tab', 'Finished Loading', [], {}, 2000)
-
-
+        print " ** Finished tab 1 update**"
 
     def updateTab2(self):
+        print " ** Starting tab 2 update**"
         self.listWidget2.clear()
         self.pushButton_com.setEnabled(False)
         self.pushButton_a2.setEnabled(False)
         self.pushButton_com.setText("...")
-        #Thread(target=self.updateGPS()).start()
         self.updateGPS()
         self.pushButton_com.setText(".....")
-        #Thread(target=self.Cellular()).start()
         self.Cellular()
         self.pushButton_com.setText("......")
-        #Thread(target=self.updatenetname()).start()
         self.updatenetname()
         self.pushButton_com.setText("Update Tab")
         self.pushButton_com.setEnabled(True)
@@ -685,26 +707,27 @@ class Ui_MainWindow(object):
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
         interface.Notify('HealthCheck', 0, 'general_refresh', 'Comms Tab', 'Finished Loading', [], {}, 2000)
+        print " ** Finished Tab 2 update **"
 
     def updateTab3(self):
+        print " ** Starting update3**"
         self.pushButton_cam.setEnabled(False)
         self.pushButton_cam.setText("....")
-        #Thread(target=self.updateImage()).start()
         self.updateImage()
         self.pushButton_cam.setText("Front camera")
         self.pushButton_cam.setEnabled(True)
 
     def updateTab3a(self):
+        print " ** Starting update3a**"
         self.pushButton_cam2.setEnabled(False)
         self.pushButton_cam2.setText("....")
-        #Thread(target=self.updateImage2()).start()
         self.updateImage2()
         self.pushButton_cam2.setText("Back Camera")
         self.pushButton_cam2.setEnabled(True)
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.0-2", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.0-3", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
@@ -714,13 +737,16 @@ class Ui_MainWindow(object):
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
     def Cellular(self):
-        import dbus
+        print " ** Starting Cellular*"
+        print " ** Importing dbus**"
+	import dbus
+	
 	regstatus = gn_cellinfo.RegStatus()
 	signalstrength = gn_cellinfo.SignalStrength()
 
 	if (regstatus[0] == 0): status = 'home'
-        elif (regstatus[0] == 1): status = 'roam'
-        elif (regstatus[0] == 2): status = 'roam_blink'
+	elif (regstatus[0] == 1): status = 'roam'
+	elif (regstatus[0] == 2): status = 'roam_blink'
 	elif (regstatus[0] == 3): status = 'no serv.'
 	elif (regstatus[0] == 4): status = 'no serv. search'
 	elif (regstatus[0] == 5): status = 'no serv. no search'
@@ -729,64 +755,48 @@ class Ui_MainWindow(object):
 	elif (regstatus[0] == 9): status = 'nsps'
 	elif (regstatus[0] == 10): status = 'nsps no cover.'
 	elif (regstatus[0] == 10): status = 'sim rejected'
-        else: status = 'unknown'
+	else: status = 'unknown'
 
 	if (regstatus[5] == 0): network_type = 'home'
 	elif (regstatus[5] == 1): network_type = 'preferred'
 	elif (regstatus[5] == 2): network_type = 'forbidden'
 	elif (regstatus[5] == 2): network_type = 'other'
 	else: network_type = 'no network'
-        services = ""
-        if (regstatus[6] & 0x02): services += 'CS '
+
+	services = ""
+	if (regstatus[6] & 0x02): services += 'CS '
 	if (regstatus[6] & 0x01): services += 'GPRS '
 	if (regstatus[6] & 0x04): services += 'EGPRS '
 	if (regstatus[6] & 0x08): services += 'HSDPA '
 	if (regstatus[6] & 0x10): services += 'HSUPA'
-
 	fraction = 1.0 / 100 * signalstrength[0]
 	text = " - %d dBm" % signalstrength[1]
 
-        self.listWidget2.addItem("Phone Signal \t\t" + text.strip())
-        #self.lbl_pSignal_Info.setText(text)
+	self.listWidget2.addItem("Phone Signal \t\t" + text.strip())
+	#self.lbl_pSignal_Info.setText(text)
 
-
-	#print "reg 1 %i" % regstatus[4]
-	#print "reg 3 %i" % regstatus[3]
-	#print "reg 1 %i" % regstatus[1]
 	cell_id = regstatus[2] & 65535
 	cell_rnc = regstatus[2] >> 16
-		
+	   
 	self.listWidget2.addItem("Cell RNC \t\t" + str(cell_rnc).strip())
-        ##
-        self.listWidget2.addItem("Cell Status \t\t" + status)
+	##
+	self.listWidget2.addItem("Cell Status \t\t" + status)
 	#self.lbl_pRNC_Info.setText(status)
-        self.listWidget2.addItem("Cell ID \t\t" + str(cell_id).strip())
+	self.listWidget2.addItem("Cell ID \t\t" + str(cell_id).strip())
 	#self.lbl_CellID_Info.setText(str(cell_id))
 
-	#print status
-	#print network_type
-	#print "regstatus %i" % regstatus[7]
-
-        ##
-        self.listWidget2.addItem("Cell Services \t\t" + services)
+	self.listWidget2.addItem("Cell Services \t\t" + services)
 	#self.lbl_pServices_Info.setText(services)
+	print " ** Finishing Cellular **"
 
-	##dbus-send --system --print-reply --type=method_call --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei
-        #bus = dbus.SystemBus()
-        #dbus_object = bus.get_object('com.nokia.phone.SIM', '/com/nokia/phone/SIM/security')
-        #dbus_interface = dbus.Interface(dbus_object, 'Phone.Sim.Security')
 
-        #print "imei"
-        #ia = dbus_interface.get_imei()
-        #ib = ia[15:]
-        #ic = ib[:15]
-        #print ic
                 
 
 
 # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, uncommented by me
 # Moved out of the class by me
 def on_error(control, error, user_data):
+    print " ** Starting on error cellular function **"
     if error == location.ERROR_USER_REJECTED_DIALOG:
         print "User didn't enable requested methods"
     elif error == location.ERROR_USER_REJECTED_SETTINGS:
@@ -802,6 +812,7 @@ def on_error(control, error, user_data):
 # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, partially commented by me
 # Moved out of the class by me
 def on_changed(device, data):
+    print " ** GPS On Changed function"
     global var_g_GPS
     global var_g_ALT
     if not device:
@@ -813,11 +824,14 @@ def on_changed(device, data):
             #Set our global variable as the location information! - scroll backup to see where it was used
             var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
             #print "altitude = %f" % device.fix[7]
-            #print device.fix
+            print " ** GPS Fix **"
+            print device.fix
             #print device.fix[4:6]
             #Seems to struggle with doing it once.... so do it 5 times to warm it up!
         for i in range(1, 5):
             if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
+                print " ** Looping GPS Fix **"
+                print device.fix
                 var_g_GPS = "lat = %f, long = %f" % device.fix[4:6]
                 #print "horizontal accuracy: %f meters" % (device.fix[6] / 100)
             if device.fix[1] & location.GPS_DEVICE_ALTITUDE_SET:
@@ -825,27 +839,37 @@ def on_changed(device, data):
                 #print "altitude = %f" % device.fix[7]
 
             data.stop()
+            print " ** Stopped GPS Fix **"
 
 # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, uncommented by me
 # Moved out of the class by me
 def on_stop(control, data):
+    print " ** Quitting data fix **"
     data.quit()
 
 # This is part of the Location api - link http://wiki.maemo.org/PyMaemo/Using_Location_API, uncommented by me
 # Moved out of the class by me
 def start_location(data):
+    print " ** Starting data fix**"
     data.start()
     return False
 
 
 # Start the main program/function
 if __name__ == "__main__":
-    
+    import sys
+    print " ** Starting Main **"
+    print " ** app = QtGui App** - Running app = QtGui.QApplication(sys.argv) **"
     app = QtGui.QApplication(sys.argv)
+    print " ** Setting Main Window**"
     MainWindow = QtGui.QMainWindow()
+    print " ** Declare the UI**"
     ui = Ui_MainWindow()
+    print " ** Draw everything and start the main function**"
     ui.setupUi(MainWindow)
+    print " ** Show everything**"
     MainWindow.show()
-
+    print " ** Waiting for quit signal - healthcheck loaded **"
     sys.exit(app.exec_())
+    print " ** sys.exit called**"
 
